<?php
/*
Plugin Name: My Video Uploads
Plugin URI: http://www.glennwedin.net/article/a-work-in-progress-wordpress-theme/16
Description: Video plugin that lists your YouTube and Vimeo uploads in a playlist with an embedded player. Use this shortcode in the editor: [videoUploads width="" height=""] Please define the width and height og the player. You can also use this php code in your template: &lt;?php do_action('myvideouploads'); ?&gt;
Version:1.1
Author: Glenn Wedin
Author URI: http://www.glennwedin.net
License: GPLv3
*/
require("youtubeAPI.class.php"); require("vimeoAPI.class.php");

class MyVideoUploads
{
	private $ytuser;  //Youtube username
	private $vmuser;  //Vimeo username
	private $ytlimit; //Limit from each of youtube and vimeo
	private $width;   //Player width
	private $height;  //Player height
	private $api;     //The youtube api object
	private $vmapi;   //The vimeop api object
	private $cacheTime; //The amount of time data should be stored in cache
	
	public function __construct()
	{
		$this->getOptions();
		if(!is_object($this->api))
		{
			if(!empty($this->ytuser) || $this->ytuser !="")
			{
			$this->api = new YoutubeAPI($this->ytuser,$this->ytlimit,$this->width,$this->height,$this->cacheTime);
			}
		}
		if(!is_object($this->vmapi))
		{
			if(!empty($this->vmuser) || $this->vmuser !="")
			{
				$this->vmapi = new VimeoAPI($this->vmuser,$this->ytlimit,$this->width,$this->height,$this->cacheTime);
			}
		}
		
		//Wordpress actions
		add_action('admin_menu',  array(&$this, 'videoUploads')); //Adding menuoption
		add_action('wp_head', array(&$this, 'addHeaderStuff'));     //adding css to head
		add_action('admin_head', array(&$this, 'addAdminHeader'));  //Adding css to head
		add_action('myvideouploads', array(&$this, 'runPlugin'));   //Action that runs the plugin from static page
		add_shortcode('videoUploads', array(&$this, 'videoUploadsShortcode')); //Creates a wordpress shortcode

		if(function_exists('wp_enqueue_script'))
		{
			wp_enqueue_script('jquery');
			wp_enqueue_script('myvideouploads',WP_PLUGIN_URL.'/my-video-uploads/js/myvideouploads.js',array('jquery'),'1.0',true);
			
		}
		
		if(isset($_POST['username']))
		{
			$this->postSettings();
		}
		else
		{
			$this->getOptions();
		}
	}
	
	public function runPlugin()
	{
		$this->getFeed();
	}
	

	
	public function getFeed()
	{
		echo '<div id="videopresenter"><div id="video_bar"><noscript class="notice">Vimeo requires javascript activated</noscript><div class="video_bar left"><ul>';
		if(!empty($this->ytuser) || $this->ytuser != "")
	   {
	   		$yt = $this->api->getFeed();
	   echo $yt['bar'];//Contains the playlist from the YouTube API
			$video_url[$yt['date'][0]] = $yt['playerUrl'][0]; //The url for the player	
			
			$feedIsset = true;	
	   }
	   echo '</ul></div>';	
	   echo '<div class="video_bar right"><ul>';
	   if(!empty($this->vmuser) || $this->vmuser != "")
	   {
	  		$vm = $this->vmapi->getFeed();
	   echo $vm['bar'];//Contains the playlist from the Vimeo API
			$video_url[$vm['date'][0]] = $vm['playerUrl'][0];//The url for the player //FIKS
			
			$feedIsset = true; //Shows the videoplayer only if username is set
	   }
	   	echo '</ul></div></div>';	
			
			if($feedIsset)
			{
			krsort($video_url);
			//var_dump($video_url);
			}
			echo '<div id="player">';
			if(isset($_GET['video_id']) && $_GET['video_id']!="")
			{
				echo '<iframe src="http://www.youtube.com/v/'.$_GET['video_id'].'?f=user_uploads&app=youtube_gdata" frameborder="0" width="'.$this->width.'" height="'.$this->height.'"></iframe>';
			}
			elseif(isset($_GET['video_vm']) && $_GET['video_vm']!="")
			{
				echo '<iframe src="http://player.vimeo.com/video/'.$_GET['video_vm'].'" frameborder=0" width="'.$this->width.'" height="'.$this->height.'"></iframe>';	
			}
			else
			{		
				if($feedIsset)
				{								//gets first array value					
					echo '<iframe src="'.reset($video_url).'" frameborder="0" width="'.$this->width.'" height="'.$this->height.'"></iframe><div id="player_desc"><p></p></div>';		}
				else
				{
					echo '<span class="notice">No videos exists or no usernames has been defined in the option page.</span> ';
				}
			}	
			echo '</div></div>'; 
	}
	
	public function videouploads()
	{
		add_options_page('My videos', 'My Video Uploads', 'manage_options', 'myvideouploads', array(&$this, 'adminPage'));	
	}
	
	public function adminPage()
	{
		echo '<div class="wrap">
			<h2>Youtube Uploads settings</h2>
			<p>Here is where you enter your username and other options</p>
			
			<form method="post" action="'.str_replace( '%7E', '~', $_SERVER['REQUEST_URI']).'">
			<label for="Username">YouTube username:<input type="text" name="username" value="'.$this->ytuser.'" /></label></br>
			<label for="Username">Vimeo username:<input type="text" name="vmusername" value="'.$this->vmuser.'" /></label></br>
			<label for="Limit">Video limit(max 50):<input style="width:40px;" type="number" min="0" max="50" name="limit" value="'.$this->ytlimit.'" /></label></br>
			<label for="width">Player width:<input style="width:40px;" type="text" name="width" value="'.$this->width.'" /></label></br>
			<label for="height">Player height:<input style="width:40px;" type="text" name="height" value="'.$this->height.'" /></label></br>
			<label for="cache">API Cache:<input style="width:40px;" type="number" name="cache" value="'.$this->cacheTime.'" />Hours</label></br>
			<span class="notice">*Please specify how many hours to store the cache. The cache reduces server load and api calls to youtube. Updates will clear the cache.</br> Width and height will be overridden by defining it in the shortcode.</span></br>
			<input type="submit" value="Save" />
			</form>
			
			<h3>Shortcode:</h3>
			<p>For use in editor for pages and posts</p>
			<p><strong>[videoUploads width="x" height="x"]</strong></p>
			</br>
			<h3>PHP-code:</h3>
			<p>For use in template</p>
			<p><strong>&lt;?php do_action("myvideouploads"); ?&gt;</strong></p>
		</div>';
		
	}
	
	private function postSettings()
	{
		$ytusername = $_POST['username'];
		update_option('ytusername',$ytusername);
		$this->ytuser = $ytusername;
		
		$vmusername = $_POST['vmusername'];
		update_option('vmusername',$vmusername);
		$this->vmuser = $vmusername;
		
		$limit = $_POST['limit'];
		update_option('ytlimit',$limit);
		$this->ytlimit = $limit;
		
		$width = $_POST['width'];
		update_option('width', $width);
		$this->width = $width;
		
		$height = $_POST['height'];
		update_option('height',$height);
		$this->height = $height;
		echo '<div class="updated"><p><strong>Options saved</strong></p></div> '; 
		
		
		//Expiration time for the cache
		$cacheExpiration  = $_POST['cache'];
		//pr hour
		update_option('cacheTime',$cacheExpiration);
		$this->cacheTime = $cacheExpiration;
		update_option('youtubeCache',"");//Clears the cache
	}
	
	private function getOptions()
	{
		$this->ytuser	 = get_option('ytusername');//Youtube
		$this->vmuser    = get_option('vmusername');//Vimeo
		$this->ytlimit	 = get_option('ytlimit');   //Video limit
		$this->width   	 = get_option('width');
		$this->height 	 = get_option('height');
		$this->cacheTime = get_option('cacheTime');
	}	
	
	public function addHeaderStuff()
	{
		echo '<link rel="stylesheet" type="text/css" href="'.WP_PLUGIN_URL.'/my-video-uploads/css/myvideouploads.css"/>';
	}
	
	public function addAdminHeader()
	{
		echo '<link rel="stylesheet" type="text/css" href="'.WP_PLUGIN_URL.'/my-video-uploads/css/admin.css"/>';
	}
	
	public function videoUploadsShortcode($atts)
	{
		extract(shortcode_atts(array(
		'width' => '360',
		'height' => '240',
		), $atts ) );
		$this->width = esc_attr($width);
		$this->height= esc_attr($height);
		$this->getFeed();
	}
	
}//End of class


if(class_exists(MyVideoUploads))
{
	$api = new MyVideoUploads();
}
?>